package com.ssj.dao.sys.imlibuser.dao;

import com.ssj.bean.weixin.libmy.domain.TbLibJoin;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.util.Map;

public interface TbClassQueryDao {
	
	 /**
	  * 查询学校的分页
	  * @param searchParam
	  * @param pageable
	  * @return
	  */
	 Page<Map<String, Object>> findLibImByPage(Map<String, Object> searchParam, Pageable pageable);
	 
	 
	 /**
	  * 查询学生的分页
	  * @param searchParam
	  * @param pageable
	  * @return
	  */
	 Page<Map<String, Object>> findStudentByPage(Map<String, Object> searchParam, Pageable pageable);
	 
	 
	 /**
	  * 查询学生添加失败的分页
	  * @param searchParam
	  * @param pageable
	  * @return
	  */
	 Page<Map<String, Object>> findStudentErrorByPage(Map<String, Object> searchParam, Pageable pageable);
	 
	 
	 /**
	  * 查询老师的分页
	  * @param searchParam
	  * @param pageable
	  * @return
	  */
	 Page<Map<String, Object>> findTeacherByPage(Map<String, Object> searchParam, Pageable pageable);
	 Page<Map<String, Object>> findHeadmasterByPage(Map<String, Object> searchParam, Pageable pageable);
	 
	 /**
	  * 查询老师添加失败的分页
	  * @param searchParam
	  * @param pageable
	  * @return
	  */
	 Page<Map<String, Object>> findTeacherErrorByPage(Map<String, Object> searchParam, Pageable pageable);

	 
	 /**
	  * 按机构的名称查询
	  * @param leagueName
	  * @return
	  */
	 TbLibJoin getTbLibJoinByLeagueName(String leagueName);

	
	 /**
	  * 查询班级的分页
	  * @param searchParam
	  * @param pageable
	  * @return
	  */
	 Page<Map<String, Object>> findClassByPage(Map<String, Object> searchParam, Pageable pageable);


	Page<Map<String, Object>> findInvalidStudentByPage(Map<String, Object> params, Pageable initPage);
}
